namespace elm { 
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::columns_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_columns_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::gravity_get( ::efl::eolian::out_traits<double>::type x,  ::efl::eolian::out_traits<double>::type y) const
{
   double __out_param_x = {};
   double __out_param_y = {};
    ::elm_obj_code_widget_gravity_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::gravity_set( ::efl::eolian::in_traits<double>::type x,  ::efl::eolian::in_traits<double>::type y) const
{
    ::elm_obj_code_widget_gravity_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::policy_get( ::efl::eolian::out_traits<Elm_Scroller_Policy>::type policy_h,  ::efl::eolian::out_traits<Elm_Scroller_Policy>::type policy_v) const
{
   Elm_Scroller_Policy __out_param_policy_h = {};
   Elm_Scroller_Policy __out_param_policy_v = {};
    ::elm_obj_code_widget_policy_get(this->_eo_ptr()
      , & __out_param_policy_h
      , & __out_param_policy_v);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Elm_Scroller_Policy>::type, Elm_Scroller_Policy>(policy_h, __out_param_policy_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Elm_Scroller_Policy>::type, Elm_Scroller_Policy>(policy_v, __out_param_policy_v);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::policy_set( ::efl::eolian::in_traits<Elm_Scroller_Policy>::type policy_h,  ::efl::eolian::in_traits<Elm_Scroller_Policy>::type policy_v) const
{
    ::elm_obj_code_widget_policy_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Scroller_Policy,  ::efl::eolian::in_traits<Elm_Scroller_Policy>::type>(policy_h)
      ,  ::efl::eolian::convert_to_c<Elm_Scroller_Policy,  ::efl::eolian::in_traits<Elm_Scroller_Policy>::type>(policy_v));
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::tabstop_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_tabstop_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::tabstop_set( ::efl::eolian::in_traits< unsigned int>::type tabstop) const
{
    ::elm_obj_code_widget_tabstop_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(tabstop));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::editable_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_editable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::editable_set( ::efl::eolian::in_traits<bool>::type editable) const
{
    ::elm_obj_code_widget_editable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(editable));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::line_numbers_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_line_numbers_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::line_numbers_set( ::efl::eolian::in_traits<bool>::type line_numbers) const
{
    ::elm_obj_code_widget_line_numbers_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(line_numbers));
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::line_width_marker_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_line_width_marker_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::line_width_marker_set( ::efl::eolian::in_traits< unsigned int>::type line_width_marker) const
{
    ::elm_obj_code_widget_line_width_marker_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(line_width_marker));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::show_whitespace_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_show_whitespace_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::show_whitespace_set( ::efl::eolian::in_traits<bool>::type show_whitespace) const
{
    ::elm_obj_code_widget_show_whitespace_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(show_whitespace));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::tab_inserts_spaces_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_tab_inserts_spaces_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::tab_inserts_spaces_set( ::efl::eolian::in_traits<bool>::type tab_inserts_spaces) const
{
    ::elm_obj_code_widget_tab_inserts_spaces_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(tab_inserts_spaces));
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::cursor_position_get( ::efl::eolian::out_traits< unsigned int>::type col,  ::efl::eolian::out_traits< unsigned int>::type line) const
{
   unsigned int __out_param_col = {};
   unsigned int __out_param_line = {};
    ::elm_obj_code_widget_cursor_position_get(this->_eo_ptr()
      , & __out_param_col
      , & __out_param_line);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< unsigned int>::type, unsigned int>(col, __out_param_col);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< unsigned int>::type, unsigned int>(line, __out_param_line);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::cursor_position_set( ::efl::eolian::in_traits< unsigned int>::type col,  ::efl::eolian::in_traits< unsigned int>::type line) const
{
    ::elm_obj_code_widget_cursor_position_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(col)
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(line));
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::lines_visible_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_lines_visible_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Code_Widget::text_left_gutter_width_get() const
{
   int __return_value =  ::elm_obj_code_widget_text_left_gutter_width_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Code_Widget::text_line_number_width_get() const
{
   int __return_value =  ::elm_obj_code_widget_text_line_number_width_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::text_tabwidth_at_column_get( ::efl::eolian::in_traits< unsigned int>::type column) const
{
   unsigned int __return_value =  ::elm_obj_code_widget_text_tabwidth_at_column_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(column));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::undo() const
{
    ::elm_obj_code_widget_undo(this->_eo_ptr());
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::columns_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_columns_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::gravity_get( ::efl::eolian::out_traits<double>::type x,  ::efl::eolian::out_traits<double>::type y) const
{
   double __out_param_x = {};
   double __out_param_y = {};
    ::elm_obj_code_widget_gravity_get(this->_eo_ptr()
      , & __out_param_x
      , & __out_param_y);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(x, __out_param_x);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<double>::type, double>(y, __out_param_y);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::gravity_set( ::efl::eolian::in_traits<double>::type x,  ::efl::eolian::in_traits<double>::type y) const
{
    ::elm_obj_code_widget_gravity_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(x)
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::policy_get( ::efl::eolian::out_traits<Elm_Scroller_Policy>::type policy_h,  ::efl::eolian::out_traits<Elm_Scroller_Policy>::type policy_v) const
{
   Elm_Scroller_Policy __out_param_policy_h = {};
   Elm_Scroller_Policy __out_param_policy_v = {};
    ::elm_obj_code_widget_policy_get(this->_eo_ptr()
      , & __out_param_policy_h
      , & __out_param_policy_v);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Elm_Scroller_Policy>::type, Elm_Scroller_Policy>(policy_h, __out_param_policy_h);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits<Elm_Scroller_Policy>::type, Elm_Scroller_Policy>(policy_v, __out_param_policy_v);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::policy_set( ::efl::eolian::in_traits<Elm_Scroller_Policy>::type policy_h,  ::efl::eolian::in_traits<Elm_Scroller_Policy>::type policy_v) const
{
    ::elm_obj_code_widget_policy_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Scroller_Policy,  ::efl::eolian::in_traits<Elm_Scroller_Policy>::type>(policy_h)
      ,  ::efl::eolian::convert_to_c<Elm_Scroller_Policy,  ::efl::eolian::in_traits<Elm_Scroller_Policy>::type>(policy_v));
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::tabstop_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_tabstop_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::tabstop_set( ::efl::eolian::in_traits< unsigned int>::type tabstop) const
{
    ::elm_obj_code_widget_tabstop_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(tabstop));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::editable_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_editable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::editable_set( ::efl::eolian::in_traits<bool>::type editable) const
{
    ::elm_obj_code_widget_editable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(editable));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::line_numbers_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_line_numbers_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::line_numbers_set( ::efl::eolian::in_traits<bool>::type line_numbers) const
{
    ::elm_obj_code_widget_line_numbers_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(line_numbers));
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::line_width_marker_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_line_width_marker_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::line_width_marker_set( ::efl::eolian::in_traits< unsigned int>::type line_width_marker) const
{
    ::elm_obj_code_widget_line_width_marker_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(line_width_marker));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::show_whitespace_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_show_whitespace_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::show_whitespace_set( ::efl::eolian::in_traits<bool>::type show_whitespace) const
{
    ::elm_obj_code_widget_show_whitespace_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(show_whitespace));
}
inline ::efl::eolian::return_traits<bool>::type Code_Widget::tab_inserts_spaces_get() const
{
   Eina_Bool __return_value =  ::elm_obj_code_widget_tab_inserts_spaces_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::tab_inserts_spaces_set( ::efl::eolian::in_traits<bool>::type tab_inserts_spaces) const
{
    ::elm_obj_code_widget_tab_inserts_spaces_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(tab_inserts_spaces));
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::cursor_position_get( ::efl::eolian::out_traits< unsigned int>::type col,  ::efl::eolian::out_traits< unsigned int>::type line) const
{
   unsigned int __out_param_col = {};
   unsigned int __out_param_line = {};
    ::elm_obj_code_widget_cursor_position_get(this->_eo_ptr()
      , & __out_param_col
      , & __out_param_line);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< unsigned int>::type, unsigned int>(col, __out_param_col);
   ::efl::eolian::assign_out< ::efl::eolian::out_traits< unsigned int>::type, unsigned int>(line, __out_param_line);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::cursor_position_set( ::efl::eolian::in_traits< unsigned int>::type col,  ::efl::eolian::in_traits< unsigned int>::type line) const
{
    ::elm_obj_code_widget_cursor_position_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(col)
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(line));
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::lines_visible_get() const
{
   unsigned int __return_value =  ::elm_obj_code_widget_lines_visible_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Code_Widget::text_left_gutter_width_get() const
{
   int __return_value =  ::elm_obj_code_widget_text_left_gutter_width_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Code_Widget::text_line_number_width_get() const
{
   int __return_value =  ::elm_obj_code_widget_text_line_number_width_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< unsigned int>::type Code_Widget::text_tabwidth_at_column_get( ::efl::eolian::in_traits< unsigned int>::type column) const
{
   unsigned int __return_value =  ::elm_obj_code_widget_text_tabwidth_at_column_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(column));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Code_Widget::undo() const
{
    ::elm_obj_code_widget_undo(this->_eo_ptr());
}
inline elm::Code_Widget::operator ::elm::Code_Widget() const { return *static_cast< ::elm::Code_Widget const*>(static_cast<void const*>(this)); }
inline elm::Code_Widget::operator ::elm::Code_Widget&() { return *static_cast< ::elm::Code_Widget*>(static_cast<void*>(this)); }
inline elm::Code_Widget::operator ::elm::Code_Widget const&() const { return *static_cast< ::elm::Code_Widget const*>(static_cast<void const*>(this)); }
} }

